@@ -284,12 +284,34 @@ def export_transaction_csv_page():
         ))
 
 
-@app.route("/export/transactions/json", methods=["GET"])
-def export_transaction_json_page():
+@app.route("/transactions/sended/validated", methods=["GET"])
+def transaction_sended_validated_page():
     logger.info(
         f"{request.remote_addr} {request.method} {request.url} {request.data}")
     return jsonify(
-        [f"{str(i[0].__dict__)} | {str(i[1])}" for i in GetMyTransaction()])
+        GetMyTransaction(sended=True, validated=True, turn_json=True))
+
+
+@app.route("/transactions/sended/not_validated", methods=["GET"])
+def transaction_sended_not_validated_page():
+    logger.info(
+        f"{request.remote_addr} {request.method} {request.url} {request.data}")
+    return jsonify(
+        GetMyTransaction(sended=True, validated=False, turn_json=True))
+
+
+@app.route("/transactions/received", methods=["GET"])
+def transaction_received_page():
+    logger.info(
+        f"{request.remote_addr} {request.method} {request.url} {request.data}")
+    return jsonify(GetMyTransaction(sended=False, turn_json=True))
+
+
+@app.route("/transactions/all", methods=["GET"])
+def transaction_all_page():
+    logger.info(
+        f"{request.remote_addr} {request.method} {request.url} {request.data}")
+    return jsonify(GetMyTransaction(turn_json=True))
 
 
 @app.route("/status", methods=["GET"])
