@@ -41,7 +41,7 @@ class Block:
         self.creator = creator
         self.genesis_time = int(time.time())
         self.start_time = int(time.time())
-        self.block_time = 11
+        self.block_time = 22
 
         self.newly = False
 
@@ -64,11 +64,11 @@ class Block:
         self.max_tx_number = 2
         self.minumum_transfer_amount = 1000
 
-        self.round_1_time = 4
+        self.round_1_time = 10
         self.round_1 = False
 
         self.round_2_starting_time = None
-        self.round_2_time = 4
+        self.round_2_time = 10
         self.round_2 = False
 
         self.consensus_timer = 0.50
@@ -78,7 +78,7 @@ class Block:
 
         self.dowload_true_block = ""
 
-    def reset_the_block(self, current_blockshash_list, custom_nodes=None):
+    def reset_the_block(self, custom_nodes=None):
         """
         When the block is verified and if block have a transaction
         and if block have at least half of the max_tx_number transaction,it saves the block
@@ -106,7 +106,6 @@ class Block:
             block2 = copy.copy(self)
             # Resetting and setting the new elements.
             self.previous_hash = self.hash
-            current_blockshash_list.append(self.previous_hash)
             self.sequance_number = self.sequance_number + 1
             self.validating_list = []
             self.hash = None
