@@ -19,7 +19,7 @@ logger = get_logger("CONSENSUS_SECOND_ROUND")
 
 
 def validate_main(block: Block) -> Block:
-    logger.info("Block approved")
+    logger.debug("Block approved")
     block.validated = True
     block.validated_time = int(time.time())
     block.round_2 = True
